@@ -19,6 +19,8 @@ See L<Catalyst>.
 
 =head1 DESCRIPTION
 
+Catalyst Utilities. 
+
 =head1 METHODS
 
 =head2 appprefix($class)
@@ -259,11 +261,12 @@ sub ensure_class_loaded {
     croak "ensure_class_loaded should be given a classname, not a filename ($class)"
         if $class =~ m/\.pm$/;
 
+    # $opts->{ignore_loaded} can be set to true, and this causes the class to be required, even
+    # if it already has symbol table entries. This is to support things like Schema::Loader, which
+    # part-generate classes in memory, but then also load some of their contents from disk.
     return if !$opts->{ ignore_loaded }
         && Class::MOP::is_class_loaded($class); # if a symbol entry exists we don't load again
 
-    # as soon as Class::MOP 0.67 + 1 is released Class::MOP::load_class($class) can be used instead
-
     # this hack is so we don't overwrite $@ if the load did not generate an error
     my $error;
     {
@@ -276,7 +279,7 @@ sub ensure_class_loaded {
 
     die $error if $error;
 
-    die "require $class was successful but the package is not defined"
+    warn "require $class was successful but the package is not defined."
         unless Class::MOP::is_class_loaded($class);
 
     return 1;
@@ -333,6 +336,45 @@ sub env_value {
     return;
 }
 
+=head2 term_width
+
+Try to guess terminal width to use with formatting of debug output
+
+All you need to get this work, is:
+
+1) Install Term::Size::Any, or
+
+2) Export $COLUMNS from your shell. 
+
+(Warning to bash users: 'echo $COLUMNS' may be showing you the bash
+variable, not $ENV{COLUMNS}. 'export COLUMNS=$COLUMNS' and you should see 
+that 'env' now lists COLUMNS.)
+
+As last resort, default value of 80 chars will be used.
+
+=cut
+
+my $_term_width;
+
+sub term_width {
+    return $_term_width if $_term_width;
+
+    my $width = eval '
+        use Term::Size::Any;
+        my ($columns, $rows) = Term::Size::Any::chars;
+        return $columns;
+    ';
+
+    if ($@) {
+        $width = $ENV{COLUMNS}
+            if exists($ENV{COLUMNS})
+            && $ENV{COLUMNS} =~ m/^\d+$/;
+    }
+
+    $width = 80 unless ($width && $width >= 80);
+    return $_term_width = $width;
+}
+
 =head1 AUTHORS
 
 Catalyst Contributors, see Catalyst.pm
